#
# spec file for package git-repo
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-repo
Version:        2.35
Release:        1.1
Summary:        The Multiple Git Repository Tool
License:        Apache-2.0
URL:            https://gerrit.googlesource.com/git-repo
Source:         %{name}-%{version}.tar.xz
# SECTION tests
BuildRequires:  git
BuildRequires:  gpg2
BuildRequires:  python3-pytest
BuildRequires:  python3-flake8
BuildRequires:  tree
# /SECTION
Requires:       python3-base
Requires:       git
BuildArch:      noarch

%description
Repo is a tool built on top of Git. Repo helps manage many Git repositories, does the uploads to
revision control systems, and automates parts of the development  workflow. Repo is not meant to
replace Git, only to make it easier to work with Git.

%prep
%setup -q
# fix shebang
sed -i -E "s|#!/usr/bin/env python.*|#!/usr/bin/python3|" repo run_tests
# remove unnecessary document
rm -f docs/windows.md

%build
# nothing to build

%install
install -Dm755 repo %{buildroot}%{_bindir}/repo

%check
%{buildroot}%{_bindir}/repo help
git config --global user.email "abuild@local.localdomain"
# test_Fetch fails on opensuse Leap 15.4 and 15.5
%if 0%{?sle_version} == 150500 || 0%{?sle_version} == 150400
PYTHONPATH=. pytest -k 'not test_Fetch'
%else
PYTHONPATH=. pytest
%endif

%files
%doc README.md docs/*.md
%{_bindir}/repo
%license LICENSE

%changelog
* Sun Jul 16 2023 Sebastian Wagner <sebix@sebix.at>
- Only execute pytest, not black and flake8 tests. We do not care about formatting
- On Leap 15.4 and 15.5 skip a test that fails there, but not on Tumbleweed
* Sun Jul 16 2023 sebix@sebix.at
- Update to version 2.35:
  * main: Fix exitcode logging
  * sync: Track new/existing project count
  * manifest: enable remove-project using path
  * update links from monorail to issuetracker
  * sync: Handle case when output isn't connected to a terminal
  * sync: Update sync progress even when _sync_dict is empty
  * sync: Handle race condition when reading active jobs
  * pager: set $LESS only when missing
  * Add envar to replace shallow clones with partial
  * sync: Show number of running fetch jobs
  * upload: use f-string
  * project: Include tags option during fetch retry
  * Parse OpenSSH versions with no SSH_EXTRAVERSION
  * sync: Show elapsed time for the longest syncing project
  * [git_trace2] Add logs for critical cmds
  * [trace2] Add absolute time on trace2 exit events
  * SUBMITTING_PATCHES: update with commit queue details
  * sync: Fix how sync times for shared projects are recorded
  * manifest: add support for revision in include
  * sync: Display total elapsed fetch time
  * [SyncAnalysisState] Preserve synctime µs
  * tests: do not allow underscores in cli options
  * upload: Add `--no-follow-tags` by default to git push
  * run_tests: Check flake8
  * Update abandon to support multiple branches
  * run_tests: Always check black and check it last
  * Format codebase with black and check formatting in CQ
  * Make black with line length 80 repo's code style
  * docs: update Focal Python version
  * upload: Skip upload if merge branch doesn't match project revision and dest_branch.
  * tests: Change docstring for CopyLinkTestCase
  * tests: Rework run_tests to use pytest directly and add vpython3 file
  * sync: Remove unused variable
  * Handle KeyboardInterrupt during repo sync
  * Update sync progress
  * project: clean up error message
  * Update bug tracking links
  * git_superproject: Log actual error fmt instead of the entire error message.
  * sync: Silence 'not found in manifest' message
  * Enable use of REPO_CONFIG_DIR to customize .repoconfig location
  * init: Silence the "rm -r .repo and try again" message if quiet
  * Fix flake8 warnings for some files
  * update_manpages.py: treat regex as raw string
  * Use 'backslashreplace' for decode
  * Use print with flush=True instead of stdout.flush
  * pylint: remove unused imports
  * update-manpages: clean up symlink in checkout
  * upload: Allow user to configure unusual commit threshold
  * repo_trace: Avoid race conditions with trace_file updating.
  * github: enable flake8 postsubmit testing
  * Use --negotiation-tip in superproject fetches.
  * tests: clean up repo_trace._TRACE_FILE patching
  * wrapper: switch to functools.lru_cache
  * tests: drop old unittest.main logic
  * sync: fix manifest sync-j handling
  * sync: Fix undefined variable in _FetchOne
  * sync: finish marking REPO_AUTO_GC=1 as deprecated.
  * test_manifest_config_properties: use assertEqual
  * sync: cleanup output when not doing GC
  * Revert "sync: save any cruft after calling git gc."
  * sync: mark REPO_AUTO_GC=1 as deprecated.
  * Fix ManifestProject.partial_clone_exclude property.
  * release-process: update to use ./release/sign-tag.py
  * wrapper.py: Replacing load_module() with exec_module()
  * Fixed wrapper related warnings in tests
  * test_capture: allow both Unix and Windows line sep
  * test_bad_path_name_checks: allow Windows path sep
  * test: Fix char encoding issues on windows
  * test: fix path seperator errors on windows
  * tox: Allow passing positional arguments
  * trace: make test timeout after 2min
  * tox: Make all tests timeout after 5min
  * Update GH Action test-ci.yml dependencies
  * tox: enable python 3.10 testing
  * Resolved DeprecationWarning for currentThread()
  * Set repo version to 2.30 (current)
  * Extract env building into a testable helper.
  * Do not set ALT object dirs when said path resolves to the same dir.
  * tests: Fix update-manpages test.
  * subcmds: display correct path multitree messages
  * update-manpages: explicitly strip color codes
  * repo_trace: drop notification of trace file name.
  * repo_trace: adjust formatting, update man page.
  * upload: track projects by path, rather than name
  * trace: restore Progress indicator.
  * sync: REPO_AUTO_GC=1 to restore old behavior.
  * Fix TRACE_FILE renaming.
  * sync: no garbage collection by default
  * Improve always-on-trace
  * GitcInit: fix gitc-init failure
  * sync: clear preciousObjects when set in error.
  * Set tracing to always on and save to .repo/TRACE_FILE.
  * tests: Make the tests pass for Python < 3.8
  * init: add --manifest-depth for shallow manifest clone
  * Revert "init: change --depth default to 1 for manifest repo"
  * sync: uninitialized variable on mirror sync failure
  * sync: do not require python 3.9
  * sync: only use --cruft when git supports it.
  * project: Add a missing call to _CopyAndLinkFiles
  * manifest: allow extend-project to override dest-branch and upstream
  * sync: use namedtuples for internal return values
  * sync: incorporate review feedback.
  * diffmanifests: Handle Missing Projects in Repo Workspace
  * update-manpages: force use of active interp
  * sync: save any cruft after calling git gc.
  * Revert "project: initialize new manifests in temp dirs"
  * sync: Correctly sync multi manifest workspaces
* Tue Aug 23 2022 sebix+novell.com@sebix.at
- Update to version 2.29:
  * manifest_xml: improve topdir accuracy.
  * init: hide identify spam when reinitializing
  * init: show a notice when reinitializing
  * stage: add missing flush before project prompt
  * upload: respect --yes with large upload confirmation
  * launcher: make missing .repo/repo/repo an error
  * launcher: initialize repo in a temp dir
  * cherry-pick: tighten up output
  * git_command: fix input passing
  * project: initialize new manifests in temp dirs
  * init: change --depth default to 1 for manifest repo
  * add a few more docs to existing funcs
  * init: use --current-branch by default
  * start: do not swallow git output all the time
  * pager: catch startup failures on Windows
  * upload: add --push-options tips & doc link
  * project: simplify GetRemote a bit
  * upload: Add ready flag to remove wip
  * commit-msg: Sync commit-msg from gerrit 3.6.1
  * sync: handle smartsync HTML responses better
  * sync: start clearing git settings that disabled pruning
  * sync: rework --jobs to provide better defaults
  * Fix the printed path of the ".repo" dir after a fresh init.
  * Omit local_manifest groups from superproject override.
  * status, diff: display correct path for multi-manifest
  * project: simplify if-statement
  * upload: add ‘--ignore-untracked-files’ option
  * man: regenerate
  * Fix Projects.shareable_dirs
  * Only sync superproject if it will be used.
* Fri May 27 2022 sebix+novell.com@sebix.at
- Update to version 2.26:
  * sync: add multi-manifest support
  * project: initial separation of shared project objects
  * upload: move label validation to core function
  * tests: switch to tempfile.TemporaryDirectory
  * project: fix --use-superproject logic for init.
* Sun May 22 2022 sebix+novell.com@sebix.at
- Update to version 2.25:
  * manifest: add submanifest.default_groups attribute
  * project: Do not exit early on --standalone-manifest.
  * project: Add missing imports
* Thu Apr 21 2022 sebix+novell.com@sebix.at
- Update to version 2.24:
  * progress: optimize progress bar updates a bit
  * Override the manifest for the entire command
  * sync: refactor use of self.manifest
  * Stop passing optparse.Values to git_superproject
  * ManifestProject: add manifest_platform
  * forall: fix multi-manifest variables.
  * git_superproject: only print beta notice once.
* Mon Apr 18 2022 sebix+novell.com@sebix.at
- Update to version 2.23:
  * manifest_xml: use Superproject to hold XML content
  * sync: respect `sync-c` manifest option
  * manifest_xml: Add Load and Unload methods
  * Fix sub manifest handling
  * init: add multi-manifest support
  * Move manifest config logic into ManifestProject
  * project: add ManifestProject.Sync()
  * project: Isolate ManifestProject from RepoProject
  * manifest_file must be an absolute path
  * trace: allow writing traces to a socket
  * manifest_xml: group for submanifest projects
* Fri Feb 25 2022 sebix+novell.com@sebix.at
- Update to version 2.22:
  * Add multi-manifest support with <submanifest> element
  * Move local-manifest check to manifest_xml.py
  * project.py: pass --recurse-submodules={value}
* Fri Feb  4 2022 sebix+novell.com@sebix.at
- remove obsolete patch fix-python-readlink.patch
- Update to version 2.21:
  * project: mark gc.log as safe to discard when migrating .git/
  * init: add an option --enable-git-lfs-filter
  * init: make bad --repo-rev settings more clear
  * project: Ignore failure to remove the sample hooks
  * branches: Fix "not in" handling
  * project: store objects in project-objects directly
  * project: move --reference handling to project-objects
  * test_project: use os.readlink instead of Path.readlink
* Tue Jan 11 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- add fix-python-readlink.patch, fixing the project for python < 3.9.
* Tue Jan 11 2022 sebix+novell.com@sebix.at
- Update to version 2.20:
  * project: prune sample hooks
  * project: drop support for symlinking internal .git files
  * project: abort a bit earlier before migrating .git/
  * Revert "sync: dropped "NOTICE: --use-superproject is in beta ..." message."
  * project: stop symlinking info dir under .git/
  * project: stop symlinking description file under .git/
  * project: stop symlinking svn under .git/
  * project: clean up now unused code
  * sync: dropped "NOTICE: --use-superproject is in beta ..." message.
  * sync: With --mirror option, don't display no-use-superproject... message.
* Mon Jan 10 2022 sebix+novell.com@sebix.at
- Update to version 2.19:
  * project: migrate worktree .git/ dirs to symlinks
  * init, sync: fixed flake8 warnings.
  * superproject: Inherit --no-use-superproject with --mirror option.
  * sync: Handle tag ref in "upstream" field
  * project: init hooks in objdir only
  * sync: link the internal-fs-layout doc into checkouts
  * git-review: add config file
  * SUBMITTING_PATCHES: link to commit message style docs
  * man: refresh pages
  * help: fix grammar in help text
* Thu Jan  6 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 2.19.
